##  Creating a Subscription Role
Users with admin rights can define and add subscription roles. To add a subscription role, follow these steps:
  1. In the administration area, select Subscription Roles.
  2. Click New Subscription Role.
  3. On the resulting page, enter the needed information:
    1. Give a name to the role.
    2. Select the subscription type. You can define the role as responsible, accountable, or observer. A role set to type All becomes available for any of the 3 subscription types while a user subscribes to a fact sheet. To learn more, see [Subscribing to Fact Sheets](https://help.sap.com/docs/leanix/ea/fact-sheet-subscription?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a16427a441014be448690c54e7cf0__subscribing_to_fact_sheets).
    3. Select the fact sheet types the role can subscribe to. You can choose multiple fact sheet types or even all. Limiting the subscription role to a particular fact sheet type makes sense when the role is specific to a certain fact sheet type. For example, the role of the Application Owner is relevant only to application fact sheets. So, while creating the Application Owner role, you could choose just the application fact sheet. For examples of commonly used subscription roles, refer to [Example Subscription Roles](https://help.sap.com/docs/leanix/ea/subscription-roles?locale=en-US&state=PRODUCTION&version=CLOUD#loio275af3a27a4410148eada5eb5d54814b__example_subscription_roles).


  1. Click Save to finish adding the role.


![Adding Subscription Role](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2744a7937a44101491d7e545c074d586_LowRes.png)
Adding Subscription Role
